entropy
========

.. currentmodule:: bcselector.information_theory.basic_approximations

.. autofunction:: entropy

conditional_entropy
===================

.. currentmodule:: bcselector.information_theory.basic_approximations

.. autofunction:: conditional_entropy

mutual_information
==================

.. currentmodule:: bcselector.information_theory.basic_approximations

.. autofunction:: mutual_information

conditional_mutual_information
==============================

.. currentmodule:: bcselector.information_theory.basic_approximations

.. autofunction:: conditional_mutual_information